@@ -629,7 +629,7 @@ class MagicianApi(object):
                          version: int,
                          is_queued=False):
         return self.__dobotlink.Magician.SetColorSensor(portName=port_name,
-                                                        port=port,
+                                                        port=port-1,
                                                         enable=enable,
                                                         version=version,
                                                         isQueued=is_queued)
@@ -645,7 +645,7 @@ class MagicianApi(object):
                             version: int,
                             is_queued=False):
         return self.__dobotlink.Magician.SetInfraredSensor(portName=port_name,
-                                                           port=port,
+                                                           port=port-1,
                                                            enable=enable,
                                                            version=version,
                                                            isQueued=is_queued)
