@@ -22,7 +22,7 @@ class RPCClient(object):
         self.__id = 0
         self.__exchange_map = {}
         self.__recv_task_timer = None
-        self.__ws: websockets.server.WebSocketServer = None
+        self.__ws: websockets.WebSocketClientProtocol = None
         self.__client_name = "DobotRPC-WSClient"
         self.__ip = ip
         self.__port = port
@@ -41,7 +41,13 @@ class RPCClient(object):
     def address(self):
         return f"{self.__ip}:{self.__port}"
 
-    def __pack_rpc(self, rpc_id: int, rpc_playload: Any,
+    @property
+    def remote_address(self):
+        return f"{self.__ws.host}:{self.__ws.port}"
+
+    def __pack_rpc(self,
+                   rpc_id: int,
+                   rpc_playload: Any,
                    method: str = None) -> str:
         if rpc_id is None:
             data = {"jsonrpc": "2.0"}
@@ -100,7 +106,8 @@ class RPCClient(object):
                     # 阻塞获取，不担心性能问题
                     ws_data = await self.__ws.recv()
                     loggers.get(LOGGER_NAME).debug(
-                        f"rpc client <<<< {ws_data}")
+                        f"C({self.address}) << S({self.remote_address}): \
+{ws_data}")
                 except Exception as e:
                     loggers.get(LOGGER_NAME).error(e, exc_info=True)
                     if self.__cb_disconnected:
@@ -157,7 +164,8 @@ class RPCClient(object):
             "id": comm_id
         }
 
-        loggers.get(LOGGER_NAME).debug(f"rpc client >>>> {payload}")
+        loggers.get(LOGGER_NAME).debug(
+            f"C({self.address}) >> S({self.remote_address}): {payload}")
         await self.__ws.send(json.dumps(payload))
 
         if cb_feedback:
@@ -204,5 +212,6 @@ class RPCClient(object):
             raise Exception("Had not connected!")
 
         rpc_packet = self.__pack_rpc(None, data, method)
-        loggers.get(LOGGER_NAME).debug(f"rpc client >>>> {rpc_packet}")
+        loggers.get(LOGGER_NAME).debug(
+            f"C({self.address}) >> S({self.remote_address}): {rpc_packet}")
         await self.__ws.send(json.dumps(rpc_packet))
