@@ -7,6 +7,8 @@ from .Magician import MagicianApi
 from .MagicBox import MagicBoxApi
 from .Lite import LiteApi
 from .M1 import M1Api
+from .MagicianGo import MagicianGoApi
 
 __all__ = ("loggers", "RPCClient", "RPCServer", "DobotlinkAdapter",
-           "NetworkError", "MagicianApi", "LiteApi", "MagicBoxApi", "M1Api")
+           "NetworkError", "MagicianApi", "LiteApi", "MagicBoxApi", "M1Api",
+           "MagicianGoApi")
